==> jc-1.4.0.tar.gz: java/text/AttributedCharacterIterator__24Attribute.h <==
// public class java.text.AttributedCharacterIterator$Attribute

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d8de555b0e6a3b60 java_text_AttributedCharacterIterator__24Attribute

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_text_AttributedCharacterIterator__24Attribute_H_
#define _JC_java_text_AttributedCharacterIterator__24Attribute_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_text_AttributedCharacterIterator__24Attribute$object;

// Typedefs
typedef struct _jc_java_text_AttributedCharacterIterator__24Attribute$sub_refs	_jc_java_text_AttributedCharacterIterator__24Attribute$sub_refs;
typedef struct _jc_java_text_AttributedCharacterIterator__24Attribute$sub_nonrefs	_jc_java_text_AttributedCharacterIterator__24Attribute$sub_nonrefs;
typedef struct _jc_java_text_AttributedCharacterIterator__24Attribute$refs	_jc_java_text_AttributedCharacterIterator__24Attribute$refs;
typedef struct _jc_java_text_AttributedCharacterIterator__24Attribute$nonrefs	_jc_java_text_AttributedCharacterIterator__24Attribute$nonrefs;
typedef struct _jc_java_text_AttributedCharacterIterator__24Attribute$object	_jc_java_text_AttributedCharacterIterator__24Attribute$object;

typedef struct _jc_java_text_AttributedCharacterIterator__24Attribute$fields_struct	_jc_java_text_AttributedCharacterIterator__24Attribute$fields_struct;
typedef const struct _jc_java_text_AttributedCharacterIterator__24Attribute$vmethods	_jc_java_text_AttributedCharacterIterator__24Attribute$vmethods;
typedef const struct _jc_java_text_AttributedCharacterIterator__24Attribute$vtable	_jc_java_text_AttributedCharacterIterator__24Attribute$vtable;
typedef const struct _jc_java_text_AttributedCharacterIterator__24Attribute$vtype	_jc_java_text_AttributedCharacterIterator__24Attribute$vtype;

// Class fields structure
struct _jc_java_text_AttributedCharacterIterator__24Attribute$fields_struct {
	struct _jc_java_text_AttributedCharacterIterator__24Attribute$object	*INPUT__5fMETHOD__5fSEGMENT;
	struct _jc_java_text_AttributedCharacterIterator__24Attribute$object	*LANGUAGE;
	struct _jc_java_text_AttributedCharacterIterator__24Attribute$object	*READING;
	jlong	serialVersionUID;
};
extern _jc_java_text_AttributedCharacterIterator__24Attribute$fields_struct _jc_java_text_AttributedCharacterIterator__24Attribute$class_fields;

// Constructors
extern void _jc_java_text_AttributedCharacterIterator__24Attribute$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_text_AttributedCharacterIterator__24Attribute$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern jboolean _jc_java_text_AttributedCharacterIterator__24Attribute$method$equals$8a15e0625571c581(_jc_env *, struct _jc_java_text_AttributedCharacterIterator__24Attribute$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_java_lang_String$object *_jc_java_text_AttributedCharacterIterator__24Attribute$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_java_text_AttributedCharacterIterator__24Attribute$object *);
extern jint _jc_java_text_AttributedCharacterIterator__24Attribute$method$hashCode$53152098849316df(_jc_env *, struct _jc_java_text_AttributedCharacterIterator__24Attribute$object *);
extern struct _jc_java_lang_Object$object *_jc_java_text_AttributedCharacterIterator__24Attribute$method$readResolve$3c2bccd3a831d3ae(_jc_env *, struct _jc_java_text_AttributedCharacterIterator__24Attribute$object *);
extern struct _jc_java_lang_String$object *_jc_java_text_AttributedCharacterIterator__24Attribute$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_text_AttributedCharacterIterator__24Attribute$object *);

// Virtual method descriptors
extern _jc_method _jc_java_text_AttributedCharacterIterator__24Attribute$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_java_text_AttributedCharacterIterator__24Attribute$method_info$getName$bec186f2ce7e1882;
extern _jc_method _jc_java_text_AttributedCharacterIterator__24Attribute$method_info$hashCode$53152098849316df;
extern _jc_method _jc_java_text_AttributedCharacterIterator__24Attribute$method_info$readResolve$3c2bccd3a831d3ae;
extern _jc_method _jc_java_text_AttributedCharacterIterator__24Attribute$method_info$toString$7ea43b33b80a3070;

// Static methods
extern void _jc_java_text_AttributedCharacterIterator__24Attribute$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_java_text_AttributedCharacterIterator__24Attribute$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_java_text_AttributedCharacterIterator__24Attribute$object *, struct _jc_java_lang_Object$object *);
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_java_text_AttributedCharacterIterator__24Attribute$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_java_text_AttributedCharacterIterator__24Attribute$object *);
	struct _jc_java_lang_Object$object	*(*readResolve$3c2bccd3a831d3ae)(_jc_env *, struct _jc_java_text_AttributedCharacterIterator__24Attribute$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_text_AttributedCharacterIterator__24Attribute$object *);
};

// Vtable
struct _jc_java_text_AttributedCharacterIterator__24Attribute$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_text_AttributedCharacterIterator__24Attribute$vmethods	java_text_AttributedCharacterIterator__24Attribute;
};

// Vtype
struct _jc_java_text_AttributedCharacterIterator__24Attribute$vtype {
	_jc_type			type;
	_jc_java_text_AttributedCharacterIterator__24Attribute$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_text_AttributedCharacterIterator__24Attribute$sub_refs {
	struct _jc_java_lang_String$object	*name;
};

// Reference instance fields (object)
struct _jc_java_text_AttributedCharacterIterator__24Attribute$refs {
    _jc_java_text_AttributedCharacterIterator__24Attribute$sub_refs	java_text_AttributedCharacterIterator__24Attribute;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_text_AttributedCharacterIterator__24Attribute$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_text_AttributedCharacterIterator__24Attribute$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_text_AttributedCharacterIterator__24Attribute$sub_nonrefs	java_text_AttributedCharacterIterator__24Attribute;
};

// Object instance structure
struct _jc_java_text_AttributedCharacterIterator__24Attribute$object {
	_jc_java_text_AttributedCharacterIterator__24Attribute$refs	refs[0];
	_jc_word		lockword;
	_jc_java_text_AttributedCharacterIterator__24Attribute$vtype	*vtype;
	_jc_java_text_AttributedCharacterIterator__24Attribute$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_text_AttributedCharacterIterator__24Attribute$vtype _jc_java_text_AttributedCharacterIterator__24Attribute$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_text_AttributedCharacterIterator__24Attribute, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_text_AttributedCharacterIterator__24Attribute$class_object;

#endif	/* _JC_java_text_AttributedCharacterIterator__24Attribute_H_ */

==> jc-1.4.6.tar.gz: java/text/AttributedCharacterIterator__24Attribute.h <==
// public class java.text.AttributedCharacterIterator$Attribute

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d8de555b0e6a3b60 java_text_AttributedCharacterIterator__24Attribute

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_text_AttributedCharacterIterator__24Attribute_H_
#define _JC_java_text_AttributedCharacterIterator__24Attribute_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_text_AttributedCharacterIterator__24Attribute$object;

// Typedefs
typedef struct _jc_java_text_AttributedCharacterIterator__24Attribute$sub_refs	_jc_java_text_AttributedCharacterIterator__24Attribute$sub_refs;
typedef struct _jc_java_text_AttributedCharacterIterator__24Attribute$sub_nonrefs	_jc_java_text_AttributedCharacterIterator__24Attribute$sub_nonrefs;
typedef struct _jc_java_text_AttributedCharacterIterator__24Attribute$refs	_jc_java_text_AttributedCharacterIterator__24Attribute$refs;
typedef struct _jc_java_text_AttributedCharacterIterator__24Attribute$nonrefs	_jc_java_text_AttributedCharacterIterator__24Attribute$nonrefs;
typedef struct _jc_java_text_AttributedCharacterIterator__24Attribute$object	_jc_java_text_AttributedCharacterIterator__24Attribute$object;

typedef struct _jc_java_text_AttributedCharacterIterator__24Attribute$fields_struct	_jc_java_text_AttributedCharacterIterator__24Attribute$fields_struct;
typedef const struct _jc_java_text_AttributedCharacterIterator__24Attribute$vmethods	_jc_java_text_AttributedCharacterIterator__24Attribute$vmethods;
typedef const struct _jc_java_text_AttributedCharacterIterator__24Attribute$vtable	_jc_java_text_AttributedCharacterIterator__24Attribute$vtable;
typedef const struct _jc_java_text_AttributedCharacterIterator__24Attribute$vtype	_jc_java_text_AttributedCharacterIterator__24Attribute$vtype;

// Class fields structure
struct _jc_java_text_AttributedCharacterIterator__24Attribute$fields_struct {
	struct _jc_java_text_AttributedCharacterIterator__24Attribute$object	*INPUT__5fMETHOD__5fSEGMENT;
	struct _jc_java_text_AttributedCharacterIterator__24Attribute$object	*LANGUAGE;
	struct _jc_java_text_AttributedCharacterIterator__24Attribute$object	*READING;
	jlong	serialVersionUID;
};
extern _jc_java_text_AttributedCharacterIterator__24Attribute$fields_struct _jc_java_text_AttributedCharacterIterator__24Attribute$class_fields;

// Constructors
extern void _jc_java_text_AttributedCharacterIterator__24Attribute$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_text_AttributedCharacterIterator__24Attribute$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_java_text_AttributedCharacterIterator__24Attribute$method$equals$8a15e0625571c581(_jc_env *, struct _jc_java_text_AttributedCharacterIterator__24Attribute$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_text_AttributedCharacterIterator__24Attribute$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_java_text_AttributedCharacterIterator__24Attribute$object *) _JC_JCNI_ATTR;
extern jint _jc_java_text_AttributedCharacterIterator__24Attribute$method$hashCode$53152098849316df(_jc_env *, struct _jc_java_text_AttributedCharacterIterator__24Attribute$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_java_text_AttributedCharacterIterator__24Attribute$method$readResolve$3c2bccd3a831d3ae(_jc_env *, struct _jc_java_text_AttributedCharacterIterator__24Attribute$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_text_AttributedCharacterIterator__24Attribute$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_text_AttributedCharacterIterator__24Attribute$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_text_AttributedCharacterIterator__24Attribute$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_java_text_AttributedCharacterIterator__24Attribute$method_info$getName$bec186f2ce7e1882;
extern _jc_method _jc_java_text_AttributedCharacterIterator__24Attribute$method_info$hashCode$53152098849316df;
extern _jc_method _jc_java_text_AttributedCharacterIterator__24Attribute$method_info$readResolve$3c2bccd3a831d3ae;
extern _jc_method _jc_java_text_AttributedCharacterIterator__24Attribute$method_info$toString$7ea43b33b80a3070;

// Static methods
extern void _jc_java_text_AttributedCharacterIterator__24Attribute$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_text_AttributedCharacterIterator__24Attribute$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_java_text_AttributedCharacterIterator__24Attribute$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_java_text_AttributedCharacterIterator__24Attribute$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_java_text_AttributedCharacterIterator__24Attribute$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*readResolve$3c2bccd3a831d3ae)(_jc_env *, struct _jc_java_text_AttributedCharacterIterator__24Attribute$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_text_AttributedCharacterIterator__24Attribute$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_text_AttributedCharacterIterator__24Attribute$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_text_AttributedCharacterIterator__24Attribute$vmethods	java_text_AttributedCharacterIterator__24Attribute;
};

// Vtype
struct _jc_java_text_AttributedCharacterIterator__24Attribute$vtype {
	_jc_type			type;
	_jc_java_text_AttributedCharacterIterator__24Attribute$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_text_AttributedCharacterIterator__24Attribute$sub_refs {
	struct _jc_java_lang_String$object	*name;
};

// Reference instance fields (object)
struct _jc_java_text_AttributedCharacterIterator__24Attribute$refs {
    _jc_java_text_AttributedCharacterIterator__24Attribute$sub_refs	java_text_AttributedCharacterIterator__24Attribute;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_text_AttributedCharacterIterator__24Attribute$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_text_AttributedCharacterIterator__24Attribute$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_text_AttributedCharacterIterator__24Attribute$sub_nonrefs	java_text_AttributedCharacterIterator__24Attribute;
};

// Object instance structure
struct _jc_java_text_AttributedCharacterIterator__24Attribute$object {
	_jc_java_text_AttributedCharacterIterator__24Attribute$refs	refs[0];
	_jc_word		lockword;
	_jc_java_text_AttributedCharacterIterator__24Attribute$vtype	*vtype;
	_jc_java_text_AttributedCharacterIterator__24Attribute$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_text_AttributedCharacterIterator__24Attribute$vtype _jc_java_text_AttributedCharacterIterator__24Attribute$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_text_AttributedCharacterIterator__24Attribute, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_text_AttributedCharacterIterator__24Attribute$class_object;

#endif	/* _JC_java_text_AttributedCharacterIterator__24Attribute_H_ */
